@@ -1,4 +1,5 @@
-from abc import ABC, abstractmethod
+from abc import ABC
+import traceback
 from typing import TYPE_CHECKING, Tuple
 
 from bclib.exception import ShortCircuitErr
@@ -52,5 +53,6 @@ class Context(ABC):
             "errorCode": error_code,
             "errorMessage": str(exception)
         }
-
+        if self.dispatcher.log_error:
+            error_object["error"] = traceback.format_exc()
         return (error_object, status_code)
